@@ -4,10 +4,13 @@ use strict;
 use warnings;
 
 use Carp;
+use My::Module::Recommend::Any qw{ __any };
 
 my @optionals = (
-    [ 'Clipboard'		=> <<'EOD' ],
+    __any( 'Clipboard'		=> <<'EOD' ),
       This module is needed to exchange data with the system clipboard.
+      If you do not intend to use the copy() or paste() methods, you do
+      not need to install this module.
 EOD
 );
 
@@ -69,35 +72,20 @@ EOD
 }
 
 sub optionals {
-    my @rslt;
-    foreach my $spec ( @optionals ) {
-	my $module = $spec->[0];
-	if ( 'ARRAY' eq ref $module ) {
-	    push @rslt, @{ $module };
-	} elsif ( ref $module ) {
-	    confess 'Module spec may not be a ', ref $module, ' reference';
-	} else {
-	    push @rslt, $module;
-	}
-    }
-    return @rslt;
+    return ( map { $_->modules() } @optionals );
 }
 
 sub recommend {
     my $need_some;
-    SPEC_LOOP:
-    foreach my $spec ( @optionals ) {
-	my ( $module, $message ) = @{ $spec };
-	foreach my $mod ( ref $module ? @{ $module } : $module ) {
-	    eval "require $mod; 1"
-		and next SPEC_LOOP;
-	}
+    foreach my $mod ( @optionals ) {
+	defined( my $msg = $mod->recommend() )
+	    or next;
 	$need_some++
 	    or warn <<'EOD';
 
-The following optional modules were not found:
+The following optional modules were not available:
 EOD
-	warn format_module_line( $module ), $message;
+	warn "\n$msg";
     }
     $need_some
 	and warn <<'EOD';
@@ -110,16 +98,10 @@ EOD
     return;
 }
 
-sub format_module_line {
-    my ( $module ) = @_;
-    ref $module
-	or return "\n    * $module is not installed.\n";
-    return "\n    * None of " . join( ', ', @{ $module } ) .
-	" is installed.\n";
-}
-
 1;
 
+__END__
+
 =head1 NAME
 
 My::Module::Recommend - Recommend modules to install. 
@@ -184,7 +166,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016 by Thomas R. Wyant, III
+Copyright (C) 2016-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
@@ -196,6 +178,4 @@ merchantability or fitness for a particular purpose.
 
 =cut
 
-__END__
-
 # ex: set textwidth=72 :
